==> kjy-center-api-0.0.10-2-sources.jar: cn/com/duiba/kjy/api/constant/WeChatConstant.java <==
package cn.com.duiba.kjy.api.constant;

/**
 * @author zhanghuifeng
 * date 2019-05-16-15:50
 */
public class WeChatConstant {

    private WeChatConstant(){

    }

    public  class  Url{

        private Url(){

        }
        public static final  String  PAY_URL = "https://api.mch.weixin.qq.com/pay/unifiedorder";

        public static final  String  PAY_QUERY_URL = "https://api.mch.weixin.qq.com/pay/orderquery";

        public static final String  ENTERPRISE_PAY_URL = "https://api.mch.weixin.qq.com/mmpaymkttransfers/promotion/transfers";

        public static final String QRCODE_CREATE_URL = "https://api.weixin.qq.com/cgi-bin/qrcode/create";

        /**
         * 企业支付查询接口地址
         */
        public static final String ENTERPRISE_PAY_QRY_URL = "https://api.mch.weixin.qq.com/mmpaymkttransfers/gettransferinfo";
    }

    public static class WechatKey{

        private WechatKey(){

        }

        public static final String APP_ID = "appid";
        public static final String MCH_ID = "mch_id";
        public static final String NONCE_STR = "nonce_str";
        public static final String SIGN = "sign";
        public static final String SIGN_TYPE = "sign_type";
        public static final String BOBY = "body";
        public static final String OUT_TRADE_NO = "out_trade_no";
        public static final String TOTAL_FEE = "total_fee";
        public static final String SPBILL_CREATE_IP = "spbill_create_ip";
        public static final String NOTIFY_URL = "notify_url";
        public static final String TRADE_TYPE = "trade_type";
        public static final String SCENE_INFO = "scene_info";
        public static final String OUT_REFUND_NO = "out_refund_no";
        public static final String REFUND_FEE  = "refund_fee";
        public static final String OPEN_ID = "openid";
        public static final String PREPAY_ID = "prepay_id";
        public static final String RETURN_CODE = "return_code";
        public static final String RESULT_CODE = "result_code";
        public static final String RETURN_MSG = "return_msg";
        public static final String PACKAGE = "package";
        public static final String TIMESTAMP ="timeStamp";
        public static final String MCH_APPID = "mch_appid";
        public static final String MCHID = "mchid";
        public static final String PARTNER_TRADE_NO = "partner_trade_no";
        public static final String CHECK_NAME = "check_name";
        public static final String AMOUNT = "amount";
        public static final String DESC = "desc";
        public static final String REFUND_NOTIFY_URL = "notify_url";
        public static final String ERR_CODE = "err_code";
        public static final String ERR_CODE_DES = "err_code_des";
        public static final String PAYMENT_AMOUNT = "payment_amount";
        public static final String STATUS = "status";
        public static final String PAYMENT_NO = "payment_no";
    }

    public  class WechatDefaultValue{

        private WechatDefaultValue(){

        }

        public static final String  SIGN_TYPE_MD5 = "MD5";
        public static final String  TRADE_TYPE_H5 = "MWEB";
        public static final String  TRADE_TYPE_JSAPI = "JSAPI";
    }

    public static class ResponseCode{

        private ResponseCode(){

        }

        public static final String  SUCCESS = "SUCCESS";
        public static final String  FAIL = "FAIL";
        public static final String FAILED = "FAILED";
        public static final String  REFUNDCLOSE = "REFUNDCLOSE";
        public static final String  PROCESSING = "PROCESSING";
        public static final String  CHANGE = "CHANGE";
        public static final String NOT_FOUND = "NOT_FOUND";
    }
}

==> kjy-center-api-0.7.78-sources.jar: cn/com/duiba/kjy/api/constant/WeChatConstant.java <==
package cn.com.duiba.kjy.api.constant;

/**
 * @author zhanghuifeng
 * date 2019-05-16-15:50
 */
public class WeChatConstant {

    private WeChatConstant(){

    }

    public  class  Url{

        private Url(){

        }
        public static final  String  PAY_URL = "https://api.mch.weixin.qq.com/pay/unifiedorder";

        public static final  String  PAY_QUERY_URL = "https://api.mch.weixin.qq.com/pay/orderquery";

        public static final String  ENTERPRISE_PAY_URL = "https://api.mch.weixin.qq.com/mmpaymkttransfers/promotion/transfers";

        public static final String QRCODE_CREATE_URL = "https://api.weixin.qq.com/cgi-bin/qrcode/create";

        public static final String UPLOAD_IMAGE_URL = "https://api.weixin.qq.com/cgi-bin/media/upload";

        /**
         * 企业支付查询接口地址
         */
        public static final String ENTERPRISE_PAY_QRY_URL = "https://api.mch.weixin.qq.com/mmpaymkttransfers/gettransferinfo";
    }

    public static class WechatKey{

        private WechatKey(){

        }

        public static final String APP_ID = "appid";
        public static final String MCH_ID = "mch_id";
        public static final String NONCE_STR = "nonce_str";
        public static final String SIGN = "sign";
        public static final String SIGN_TYPE = "sign_type";
        public static final String BOBY = "body";
        public static final String OUT_TRADE_NO = "out_trade_no";
        public static final String TOTAL_FEE = "total_fee";
        public static final String SPBILL_CREATE_IP = "spbill_create_ip";
        public static final String NOTIFY_URL = "notify_url";
        public static final String TRADE_TYPE = "trade_type";
        public static final String SCENE_INFO = "scene_info";
        public static final String OUT_REFUND_NO = "out_refund_no";
        public static final String REFUND_FEE  = "refund_fee";
        public static final String OPEN_ID = "openid";
        public static final String PREPAY_ID = "prepay_id";
        public static final String RETURN_CODE = "return_code";
        public static final String RESULT_CODE = "result_code";
        public static final String RETURN_MSG = "return_msg";
        public static final String PACKAGE = "package";
        public static final String TIMESTAMP ="timeStamp";
        public static final String MCH_APPID = "mch_appid";
        public static final String MCHID = "mchid";
        public static final String PARTNER_TRADE_NO = "partner_trade_no";
        public static final String CHECK_NAME = "check_name";
        public static final String AMOUNT = "amount";
        public static final String DESC = "desc";
        public static final String REFUND_NOTIFY_URL = "notify_url";
        public static final String ERR_CODE = "err_code";
        public static final String ERR_CODE_DES = "err_code_des";
        public static final String PAYMENT_AMOUNT = "payment_amount";
        public static final String STATUS = "status";
        public static final String PAYMENT_NO = "payment_no";
        public static final String PAYMENT_TIME = "payment_time";
        public static final String REASON = "reason";
        public static final String DETAIL_ID = "detail_id";
    }

    public  class WechatDefaultValue{

        private WechatDefaultValue(){

        }

        public static final String  SIGN_TYPE_MD5 = "MD5";
        public static final String  TRADE_TYPE_H5 = "MWEB";
        public static final String  TRADE_TYPE_JSAPI = "JSAPI";
    }

    public static class ResponseCode{

        private ResponseCode(){

        }

        public static final String  SUCCESS = "SUCCESS";
        public static final String  FAIL = "FAIL";
        public static final String FAILED = "FAILED";
        public static final String  REFUNDCLOSE = "REFUNDCLOSE";
        public static final String  PROCESSING = "PROCESSING";
        public static final String  CHANGE = "CHANGE";
        public static final String NOT_FOUND = "NOT_FOUND";
    }
}
